# SpectroscopyToolbox

![Tests](https://github.com/GES-ppravatto/SpectroscopyToolbox/actions/workflows/tests.yml/badge.svg)

A small collection of python-based tools useful in the analysis of experimental spectroscopic data
